@@ -33,7 +33,7 @@ class DebImporter(Pulp2to3Importer):
         """
         pulp2_config = pulp2importer.pulp2_config
         base_config, name = cls.parse_base_config(pulp2importer, pulp2_config)
-        base_config['distributions'] = pulp2_config.get('releases').replace(',', ' ')
+        base_config['distributions'] = pulp2_config.get('releases', 'stable').replace(',', ' ')
         components = pulp2_config.get('components')
         if components:
             base_config['components'] = components.replace(',', ' ')
